**************************************************************
*** Programs to calculate total, indirect and direct effects in the SLX models in the Drolc, Gandrud and Williams PSJ project
***
*** Created: 5-12-15
*** Modified: 5-2-19
***
**************************************************************

mata: mata clear



**************************************************************
****************** PROGRAMS **********************************
**************************************************************

version 10.1
mata:
mata set matastrict on 
void calceffslx2(real matrix draws, real matrix dub1, real matrix dub2, real scalar sims)
{
	real matrix o1, o2, effect
	real scalar i, teffect, teffect_se, deffect, deffect_se, ieffect, ieffect_se

	effect = J(sims,6,.)
	for(i=1; i<=sims; i++) {
		o1 = draws[i,2]*dub1
		o2 = draws[i,3]*dub2
		
		effect[i,1]=1/rows(dub1)*sum(o1)
		effect[i,2]=1/rows(dub1)*trace(o1)
		effect[i,3]=1/rows(dub1)*(sum(o1) - trace(o1))
		
		effect[i,4]=1/rows(dub2)*sum(o2)
		effect[i,5]=1/rows(dub2)*trace(o2)
		effect[i,6]=1/rows(dub2)*(sum(o2) - trace(o2))		
	}

	teffect = mean(draws[,1] + effect[,1] + effect[,4])
	teffect_se = sqrt(variance(draws[,1] + effect[,1] + effect[,4]))
	deffect = mean(draws[,1] + effect[,2] + effect[,5])
	deffect_se = sqrt(variance(draws[,1] + effect[,2] + effect[,5]))
	ieffect = mean(effect[,3] + effect[,6])
	ieffect_se = sqrt(variance(effect[,3] + effect[,6]))
	
	st_matrix("r(mateffect)", effect)
	
	st_numscalar("r(teffect)", teffect)
	st_numscalar("r(teffect_se)", teffect_se)
	st_numscalar("r(deffect)", deffect)
	st_numscalar("r(deffect_se)", deffect_se)
	st_numscalar("r(ieffect)", ieffect)
	st_numscalar("r(ieffect_se)", ieffect_se)
}
end

version 10.1
mata:
mata set matastrict on 
void calceffslx1(real matrix draws, real matrix dub1, real scalar sims)
{
	real matrix o1, effect
	real scalar i, teffect, teffect_se, deffect, deffect_se, ieffect, ieffect_se, deffect_o0, deffect_se_o0, teffect_o1, teffect_se_o1, deffect_o1, deffect_se_o1, ieffect_o1, ieffect_se_o1

	effect = J(sims,3,.)
	for(i=1; i<=sims; i++) {
		o1 = draws[i,2]*dub1
		
		effect[i,1]=1/rows(dub1)*sum(o1)
		effect[i,2]=1/rows(dub1)*trace(o1)
		effect[i,3]=1/rows(dub1)*(sum(o1) - trace(o1))
	}

	teffect_o1 = mean(effect[,1])
	teffect_se_o1 = sqrt(variance(effect[,1]))
	deffect_o1 = mean(effect[,2])
	deffect_se_o1 = sqrt(variance(effect[,2]))
	ieffect_o1 = mean(effect[,3])
	ieffect_se_o1 = sqrt(variance(effect[,3]))
	
	deffect_o0 = mean(draws[,1])
	deffect_se_o0 = sqrt(variance(draws[,1]))
	
	teffect = mean(draws[,1] + effect[,1])
	teffect_se = sqrt(variance(draws[,1] + effect[,1]))
	deffect = mean(draws[,1] + effect[,2])
	deffect_se = sqrt(variance(draws[,1] + effect[,2]))
	ieffect = mean(effect[,3])
	ieffect_se = sqrt(variance(effect[,3]))
	
	st_matrix("r(mateffect)", effect)

	st_numscalar("r(teffect_o1)", teffect_o1)
	st_numscalar("r(teffect_se_o1)", teffect_se_o1)
	st_numscalar("r(deffect_o1)", deffect_o1)
	st_numscalar("r(deffect_se_o1)", deffect_se_o1)
	st_numscalar("r(ieffect_o1)", ieffect_o1)
	st_numscalar("r(ieffect_se_o1)", ieffect_se_o1)
	
	st_numscalar("r(deffect_o0)", deffect_o0)
	st_numscalar("r(deffect_se_o0)", deffect_se_o0)
	
	st_numscalar("r(teffect)", teffect)
	st_numscalar("r(teffect_se)", teffect_se)
	st_numscalar("r(deffect)", deffect)
	st_numscalar("r(deffect_se)", deffect_se)
	st_numscalar("r(ieffect)", ieffect)
	st_numscalar("r(ieffect_se)", ieffect_se)
}
end
